use dioxus::document::Stylesheet;
use dioxus::prelude::*;
use dioxus_sdk::storage::{LocalStorage, use_synced_storage};
use dioxus_sdk::theme::{get_system_theme, SystemTheme};

use super::{Route, Theme};
use crate::language::{Language, LanguageManager};

const FAVICON: Asset = asset!("/assets/favicon.ico");
const MAIN_CSS: Asset = asset!("/assets/styles/main.scss");

#[component]
pub(super) fn App() -> Element {
    let sig = use_synced_storage::<LocalStorage, _>("language".to_string(), || Language::EnUS);
    let theme = use_synced_storage::<LocalStorage, _>("theme".to_string(), || {
        if get_system_theme().unwrap_or(SystemTheme::Light) == SystemTheme::Dark {
            Theme::Dark
        } else {
            Theme::Light
        }
    });

    use_context_provider(|| sig);
    use_context_provider(|| theme);
    use_context_provider(|| LanguageManager::new(sig()));

    rsx! {
        document::Link { rel: "icon", href: FAVICON }
        Stylesheet { href: MAIN_CSS }

        div {
            id: "container",
            "theme": theme,
            
            Router::<Route> {}
        }
    }
}
