use chrono::{Datelike, Local, NaiveDate};

pub fn calculate_age(birth_date: NaiveDate) -> (i32, u32, u32) {
    let today = Local::now().naive_local();

    let mut years = today.year() - birth_date.year();
    let mut months = today.month() as i32 - birth_date.month() as i32;
    let mut days = today.day() as i32 - birth_date.day() as i32;

    if days < 0 {
        months -= 1;
        let prev_month = if today.month() == 1 { 12 } else { today.month() - 1 };
        let year = if today.month() == 1 { today.year() - 1 } else { today.year() };
        days += last_day_of_month(year, prev_month) as i32;
    }

    if months < 0 {
        years -= 1;
        months += 12;
    }

    (years, months as u32, days as u32)
}

fn last_day_of_month(year: i32, month: u32) -> u32 {
    let first_next = if month == 12 {
        NaiveDate::from_ymd_opt(year + 1, 1, 1)
    } else {
        NaiveDate::from_ymd_opt(year, month + 1, 1)
    };
    
    first_next.unwrap().pred_opt().unwrap().day()
}