use chrono::NaiveDate;
use dioxus::prelude::*;

use crate::components::Button;
use crate::language::Language;
use crate::utils::date::calculate_age;
use crate::{map, Theme};

static GENRES: &'static [&str] = &["black metal", "doom metal", "DSBM", "nu metal", "hard rock"];
static BANDS: &'static [&str] = &[
    "Mgła",
    "Behemoth",
    "Burzum",
    "Arkona",
    "Draconian",
    "Darkthrone",
    "Venom",
    "Slipknot",
    "None",
    "Lil Peep",
    "Alphaville",
    "MGMT",
    "ABBA",
    "Evanescence",
];

#[component]
pub fn About(props: super::Props) -> Element {
    let mut lang = use_context::<Signal<Language>>();
    let mut theme = use_context::<Signal<Theme>>();

    let birth_date = NaiveDate::from_ymd_opt(2007, 6, 25).unwrap();
    let diff = calculate_age(birth_date);
    let ctx = props.ctx.lock().unwrap();

    rsx! {
        p { id: "about", {ctx.tr("about", map! {
            "years" => diff.0,
            "months" => diff.1,
            "days" => diff.2
        })} }

        div {
            class: "button-stack",
            Button {
                onclick: move |_| { *theme.write() = theme().different() },
                primary: true,
                icon: Some(if theme() == Theme::Light {
                    "/assets/icons/sun.svg"
                } else {
                    "/assets/icons/moon.svg"
                }),
                {ctx.tr("switch_theme", map!(
                    "theme" => ctx.tr(&format!("theme.{}", theme().different()), None)
                ))}
            }

            Button {
                onclick: move |_| { *lang.write() = "pl-PL".into(); },
                icon: "/assets/icons/countries/pl.svg",
                disable_effects: true,
                {ctx.tr("languages.pl", None)}
            }

            Button {
                onclick: move |_| { *lang.write() = "en-US".into(); },
                icon: "/assets/icons/countries/us.svg",
                disable_effects: true,
                {ctx.tr("languages.en-US", None)}
            }

            Button {
                onclick: move |_| { *lang.write() = "en-GB".into(); },
                icon: "/assets/icons/countries/uk.svg",
                disable_effects: true,
                {ctx.tr("languages.en-GB", None)}
            }
        }

        h2 { {ctx.tr("headers.facts", None)} }
        div {
            class: "button-stack",
            for item in ctx.raw("about_me").unwrap().as_array().unwrap() {
                Button {
                    {item.as_str()}
                }
            }
        }

        h2 { {ctx.tr("headers.skills", None)} }
        div {
            class: "button-stack",
            for item in ctx.raw("skills").unwrap().as_array().unwrap() {
                Button {
                    {item.as_str()}
                }
            }
        }

        h2 { id: "music", {ctx.tr("headers.music", None)} }
        p { i { {ctx.tr("broad_music_spectrum", None)} } }
        div {
            class: "button-stack",
            for item in GENRES {
                Button {
                    {item}
                }
            }
        }

        h2 { {ctx.tr("headers.bands", None)} }
        div {
            class: "button-stack",
            for item in BANDS {
                Button {
                    {item}
                }
            }
        }
    }
}
