use dioxus::prelude::*;
use crate::components::Button;

struct Link {
    content: &'static str,
    icon: &'static str,
    link: Option<&'static str>,
    primary: bool,
    disabled: bool
}

#[component]
pub fn Links(props: super::Props) -> Element {
    let ctx = props.ctx.lock().unwrap();

    rsx! {
        h2 { id: "contact", {ctx.tr("section.fediverse", None)} }
        div {
            class: "button-stack",
            for link in FEDIVERSE_LINKS {
                Button {
                    icon: link.icon,
                    link: link.link,
                    primary: link.primary,
                    disabled: link.disabled,
                    {ctx.tr(link.content, None)}
                }
            }
        }

        h2 { {ctx.tr("section.contact", None)} }
        div {
            class: "button-stack",
            for link in CONTACT_WAYS {
                Button {
                    icon: link.icon,
                    link: link.link,
                    primary: link.primary,
                    disabled: link.disabled,
                    {ctx.tr(link.content, None)}
                }
            }
        }

        h2 { id: "links", {ctx.tr("section.links", None)} }
        div {
            class: "button-stack",
            for link in LINKS {
                Button {
                    icon: link.icon,
                    link: link.link,
                    primary: link.primary,
                    disabled: link.disabled,
                    {ctx.tr(link.content, None)}
                }
            }
        }
    }
}

static FEDIVERSE_LINKS: &'static [Link] = &[
    Link {
        content: "fediverse.pleroma",
        icon: "/assets/icons/fediverse/pleroma.svg",
        link: Some("https://social.sador.me/@boss"),
        primary: true,
        disabled: false
    },
    Link{
        content: "fediverse.pixelfed",
        icon: "/assets/icons/fediverse/pixelfed.svg",
        link: Some("https://pix.sador.me/boss"),
        primary: true,
        disabled: false
    },
    Link{
        content: "fediverse.peertube",
        icon: "/assets/icons/fediverse/peertube.svg",
        link: Some("https://tube.sador.me/c/sador"),
        primary: true,
        disabled: false
    }
];

static CONTACT_WAYS: &'static [Link] = &[
    Link {
        content: "contact.matrix",
        icon: "/assets/icons/matrix.svg",
        link: Some("https://matrix.to/#/@boss:sador.me"),
        primary: false,
        disabled: false
    },
    Link {
        content: "contact.signal",
        icon: "/assets/icons/signal.svg",
        link: None,
        primary: false,
        disabled: false
    }
];

static LINKS: &'static [Link] = &[
    Link {
        content: "link.pgp",
        icon: "/assets/icons/pgp.svg",
        link: Some("/assets/pgp.asc"),
        primary: true,
        disabled: false
    },
    Link {
        content: "link.uptime",
        icon: "/assets/icons/uptime.svg",
        link: Some("https://health.sador.me/status/aio"),
        primary: false,
        disabled: false
    },
    Link {
        content: "link.email",
        icon: "/assets/icons/email.svg",
        link: Some("mailto:contact@sador.me?subject=[sador.me] ..."),
        primary: false,
        disabled: false
    },
    Link {
        content: "link.gitea",
        icon: "/assets/icons/gitea.svg",
        link: Some("https://git.sador.me"),
        primary: false,
        disabled: false
    },
    Link {
        content: "link.instagram",
        icon: "/assets/icons/instagram.svg",
        link: Some("https://instagram.com/sadorowo"),
        primary: false,
        disabled: true
    }
];
